# remirepo/fedora spec file for php-tecnickcom-tc-lib-pdf-parser
#
# Copyright (c) 2015-2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global gh_commit    668b3c41d28d7791caed257e457279f89df4151a
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global c_vendor     tecnickcom
%global gh_owner     tecnickcom
%global gh_project   tc-lib-pdf-parser
%global php_project  %{_datadir}/php/Com/Tecnick/Pdf/Parser
%global with_tests   0%{!?_without_tests:1}

Name:           php-%{gh_owner}-%{gh_project}
Version:        2.4.33
Release:        1%{?dist}
Summary:        PHP library to parse PDF documents

License:        LGPL-3.0-or-later
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{name}-%{version}-%{?gh_short}.tar.gz

BuildArch:      noarch
%if %{with_tests}
# For tests
# remirepo:1
%if 0%{?fedora} >= 37 || 0%{?rhel} >= 10
%global phpunit %{_bindir}/phpunit10
BuildRequires:  phpunit10
# remirepo:4
%else
%global phpunit %{_bindir}/phpunit9
BuildRequires:  phpunit9 >= 9.5.27
%endif
BuildRequires:  php(language) >= 5.4
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires: (php-composer(%{c_vendor}/tc-lib-pdf-filter) >= 1.4    with php-composer(%{c_vendor}/tc-lib-pdf-filter) < 2)
%else
BuildRequires:  php-%{c_vendor}-tc-lib-pdf-filter           <  2
BuildRequires:  php-%{c_vendor}-tc-lib-pdf-filter           >= 1.4
%endif
BuildRequires:  php-pcre
%endif
BuildRequires:  php-fedora-autoloader-devel

# From composer.json, "require": {
#        "php": ">=5.4"
#        "ext-pcre": "*",
#        "tecnickcom/tc-lib-pdf-filter": "^1.4"
Requires:       php(language) >= 5.4
Requires:       php-pcre
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
Requires:      (php-composer(%{c_vendor}/tc-lib-pdf-filter) >= 1.4    with php-composer(%{c_vendor}/tc-lib-pdf-filter) < 2)
%else
Requires:       php-%{c_vendor}-tc-lib-pdf-filter           <  2
Requires:       php-%{c_vendor}-tc-lib-pdf-filter           >= 1.4
%endif
# From phpcompatinfo report for version 2.1.0
# None
BuildRequires:  php-fedora-autoloader-devel

# Composer
Provides:       php-composer(%{c_vendor}/%{gh_project}) = %{version}
# Upstream package name
Provides:       php-%{gh_project} = %{version}


%description
PHP library to parse PDF documents.

The initial source code has been extracted from TCPDF (http://www.tcpdf.org).


%prep
%setup -q -n %{gh_project}-%{gh_commit}

: Sanity check
grep -q '^%{version}$' VERSION

: Fix the examples
sed -e 's:^require:////require:' \
    -e 's:^//require:require:'   \
    -e 's:../resources/test/::'  \
    -i example/*php
ln resources/test/example_036.pdf example


%build
phpab --template fedora --output src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{_datadir}/php/Com/Tecnick/Pdf/Filter/autoload.php',
]);
EOF


%install
mkdir -p   $(dirname %{buildroot}%{php_project})
cp -pr src %{buildroot}%{php_project}


%check
%if %{with_tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require '%{buildroot}%{php_project}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('Test\\', dirname(__DIR__) . '/test');
EOF

ret=0
for cmdarg in php "php80 %{_bindir}/phpunit9" php81 php82 php83; do
   if which $cmdarg; then
      set $cmdarg
      cp phpunit.xml.dist phpunit.xml
      $1 ${2:-%{phpunit}} --migrate-configuration || :
      $1 ${2:-%{phpunit}} --no-coverage || ret=1
   fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
# remirepo:1
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc composer.json
%doc *.md example
%{php_project}


%changelog
* Mon Oct 23 2023 Remi Collet <remi@remirepo.net> - 2.4.33-1
- update to 2.4.33 (no change)

* Thu Oct 12 2023 Remi Collet <remi@remirepo.net> - 2.4.31-1
- update to 2.4.31

* Tue Oct 10 2023 Remi Collet <remi@remirepo.net> - 2.4.26-1
- update to 2.4.26

* Tue Oct 10 2023 Remi Collet <remi@remirepo.net> - 2.4.23-1
- update to 2.4.23

* Fri Sep  8 2023 Remi Collet <remi@remirepo.net> - 2.4.22-1
- update to 2.4.22 (no change)

* Wed May 24 2023 Remi Collet <remi@remirepo.net> - 2.4.18-1
- update to 2.4.18 (no change)

* Fri May  5 2023 Remi Collet <remi@remirepo.net> - 2.4.17-1
- update to 2.4.17 (no change)

* Thu May  4 2023 Remi Collet <remi@remirepo.net> - 2.4.16-1
- update to 2.4.16 (no change)

* Wed May  3 2023 Remi Collet <remi@remirepo.net> - 2.4.14-1
- update to 2.4.14 (no change)

* Thu Dec 22 2022 Remi Collet <remi@remirepo.net> - 2.4.13-1
- update to 2.4.13 (no change)

* Tue Jun 14 2022 Remi Collet <remi@remirepo.net> - 2.4.9-1
- update to 2.4.9 (no change)

* Mon Jan  3 2022 Remi Collet <remi@remirepo.net> - 2.4.7-1
- update to 2.4.7 (no change)

* Mon Feb  8 2021 Remi Collet <remi@remirepo.net> - 2.4.4-1
- update to 2.4.4 (no change)

* Mon Dec 21 2020 Remi Collet <remi@remirepo.net> - 2.4.1-1
- update to 2.4.1
- switch to classmap autoloader

* Fri Jan  3 2020 Remi Collet <remi@remirepo.net> - 2.3.9-1
- update to 2.3.9

* Mon Jun 25 2018 Remi Collet <remi@remirepo.net> - 2.3.8-1
- update to 2.3.8 (no change)

* Mon May 14 2018 Remi Collet <remi@remirepo.net> - 2.3.7-1
- update to 2.3.7 (no change)
- switch to phpunit7
- use range dependencies

* Tue Jan  2 2018 Remi Collet <remi@remirepo.net> - 2.3.6-1
- Update to 2.3.6 (no change)

* Sun Feb 12 2017 Remi Collet <remi@remirepo.net> - 2.3.5-1
- update to 2.3.5 (no change)

* Fri Sep  2 2016 Remi Collet <remi@fedoraproject.org> - 2.3.3-1
- update to 2.3.3 (no change)
- raise dependency on tecnickcom/tc-lib-pdf-filter >= 1.3.3

* Tue Jun 14 2016 Remi Collet <remi@fedoraproject.org> - 2.3.0-1
- update to 2.3.0 (no change)

* Fri Mar  4 2016 Remi Collet <remi@fedoraproject.org> - 2.2.3-1
- update to 2.2.3 (no change)

* Tue Jan 12 2016 Remi Collet <remi@fedoraproject.org> - 2.2.2-1
- update to 2.2.2

* Tue Dec 15 2015 Remi Collet <remi@fedoraproject.org> - 2.2.1-1
- update to 2.2.1 (no change)

* Fri Dec 11 2015 Remi Collet <remi@fedoraproject.org> - 2.2.0-1
- update to 2.2.0 (no change)
- raise dependency on php >= 5.4
- raise dependency on tecnickcom/tc-lib-pdf-filter ^1.2.0

* Fri Dec 11 2015 Remi Collet <remi@fedoraproject.org> - 2.1.22-1
- update to 2.1.22 (no change)

* Mon Dec  7 2015 Remi Collet <remi@fedoraproject.org> - 2.1.20-1
- update to 2.1.20 (no change)

* Thu Dec  3 2015 Remi Collet <remi@fedoraproject.org> - 2.1.18-1
- update to 2.1.18 (no change)

* Fri Nov 27 2015 Remi Collet <remi@fedoraproject.org> - 2.1.17-1
- update to 2.1.17 (no change)

* Wed Nov 25 2015 Remi Collet <remi@fedoraproject.org> - 2.1.16-1
- update to 2.1.16 (no change)

* Fri Nov 20 2015 Remi Collet <remi@fedoraproject.org> - 2.1.12-1
- update to 2.1.12 (no change)

* Fri Nov 20 2015 Remi Collet <remi@fedoraproject.org> - 2.1.10-1
- update to 2.1.10 (no change)

* Wed Nov 18 2015 Remi Collet <remi@fedoraproject.org> - 2.1.8-1
- update to 2.1.8 (no change)
- run test suite with both PHP 5 and 7 when available

* Tue Oct 20 2015 Remi Collet <remi@fedoraproject.org> - 2.1.7-1
- update to 2.1.7 (no change)

* Fri Sep 25 2015 Remi Collet <remi@fedoraproject.org> - 2.1.6-1
- update to 2.1.6 (no change)

* Sun Sep 13 2015 Remi Collet <remi@fedoraproject.org> - 2.1.4-1
- update to 2.1.4
- provide php-composer(tecnickcom/tc-lib-pdf-parser)

* Fri Jul 24 2015 Remi Collet <remi@fedoraproject.org> - 2.1.3-1
- update to 2.1.3 (no change)

* Thu Jul  2 2015 Remi Collet <remi@fedoraproject.org> - 2.1.2-1
- update to 2.1.2
- drop patches merged/fixed upstream

* Thu Jul  2 2015 Remi Collet <remi@fedoraproject.org> - 2.1.0-1
- initial package, version 2.1.0
- open https://github.com/tecnickcom/tc-lib-pdf-parser/pull/1
  fix autoloader
- open https://github.com/tecnickcom/tc-lib-pdf-parser/pull/2
  php < 5.5 compatibility

